@@ -3,12 +3,10 @@ from logging import getLogger
 from multiprocessing.pool import ThreadPool
 
 from eltyer.configuration.config import Config
-from eltyer.utils.version import get_version
 from eltyer.models import OrderSide, OrderType, Order, Position, Portfolio, \
     OrderStatus
 from eltyer.exceptions import ClientException
 
-VERSION = (0, 2, 0, 'alpha', 0)
 
 logger = getLogger(__name__)
 
@@ -160,6 +158,8 @@ class Client:
     def get_positions(self, json=False):
         self.check_context()
 
+        portfolio = self.get_portfolio()
+
         response = requests.get(
             f"{self.config.HOST_ORDER_SERVICE}"
             f"{self.config.POSITIONS_ENDPOINT.format(algorithm_id=self.algorithm_id)}",
@@ -172,7 +172,15 @@ class Client:
         if json:
             return data["items"]
 
-        positions = []
+        # Add unallocated as a position
+        positions = [
+            Position.from_dict(
+                {
+                    "symbol": portfolio.trading_symbol,
+                    "amount": portfolio.unallocated
+                }
+            )
+        ]
 
         for position_data in data["items"]:
             positions.append(Position.from_dict(position_data))
@@ -246,7 +254,6 @@ class Client:
 
 __all__ = [
     "Client",
-    "get_version",
     "OrderType",
     "OrderStatus",
     "OrderSide",
